@@ -71,31 +71,31 @@ void AddDialogTest::testBasicWidgets_data()
 
     const auto writeMimeTypes = m_pluginManager.supportedWriteMimeTypes();
 
-    if (writeMimeTypes.contains(QStringLiteral("application/zip"))) {
+    if (writeMimeTypes.contains(QLatin1String("application/zip"))) {
         QTest::newRow("zip") << QStringLiteral("application/zip") << true << 3 << 7;
     } else {
         qDebug() << "zip format not available, skipping test.";
     }
 
-    if (writeMimeTypes.contains(QStringLiteral("application/x-7z-compressed"))) {
+    if (writeMimeTypes.contains(QLatin1String("application/x-7z-compressed"))) {
         QTest::newRow("7z") << QStringLiteral("application/x-7z-compressed") << true << 3 << 7;
     } else {
         qDebug() << "7z format not available, skipping test.";
     }
 
-    if (writeMimeTypes.contains(QStringLiteral("application/vnd.rar"))) {
+    if (writeMimeTypes.contains(QLatin1String("application/vnd.rar"))) {
         QTest::newRow("rar") << QStringLiteral("application/vnd.rar") << true << 2 << 5;
     } else {
         qDebug() << "rar format not available, skipping test.";
     }
 
-    if (writeMimeTypes.contains(QStringLiteral("application/x-lrzip-compressed-tar"))) {
+    if (writeMimeTypes.contains(QLatin1String("application/x-lrzip-compressed-tar"))) {
         QTest::newRow("tarlrzip") << QStringLiteral("application/x-lrzip-compressed-tar") << true << 3 << 7;
     } else {
         qDebug() << "tar.lrzip format not available, skipping test.";
     }
 
-    if (writeMimeTypes.contains(QStringLiteral("application/x-tzo"))) {
+    if (writeMimeTypes.contains(QLatin1String("application/x-tzo"))) {
         QTest::newRow("tarlzop") << QStringLiteral("application/x-tzo") << true << 3 << 7;
     } else {
         qDebug() << "tar.lzo format not available, skipping test.";
